==> google_cloud_dialogflow_cx-0.7.0-py2.py3-none-any.whl: google/cloud/dialogflowcx_v3/services/transition_route_groups/pagers.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import (
    Any,
    AsyncIterable,
    Awaitable,
    Callable,
    Iterable,
    Sequence,
    Tuple,
    Optional,
)

from google.cloud.dialogflowcx_v3.types import transition_route_group


class ListTransitionRouteGroupsPager:
    """A pager for iterating through ``list_transition_route_groups`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.dialogflowcx_v3.types.ListTransitionRouteGroupsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``transition_route_groups`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListTransitionRouteGroups`` requests and continue to iterate
    through the ``transition_route_groups`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.dialogflowcx_v3.types.ListTransitionRouteGroupsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., transition_route_group.ListTransitionRouteGroupsResponse],
        request: transition_route_group.ListTransitionRouteGroupsRequest,
        response: transition_route_group.ListTransitionRouteGroupsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.dialogflowcx_v3.types.ListTransitionRouteGroupsRequest):
                The initial request object.
            response (google.cloud.dialogflowcx_v3.types.ListTransitionRouteGroupsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = transition_route_group.ListTransitionRouteGroupsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(
        self,
    ) -> Iterable[transition_route_group.ListTransitionRouteGroupsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterable[transition_route_group.TransitionRouteGroup]:
        for page in self.pages:
            yield from page.transition_route_groups

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListTransitionRouteGroupsAsyncPager:
    """A pager for iterating through ``list_transition_route_groups`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.dialogflowcx_v3.types.ListTransitionRouteGroupsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``transition_route_groups`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListTransitionRouteGroups`` requests and continue to iterate
    through the ``transition_route_groups`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.dialogflowcx_v3.types.ListTransitionRouteGroupsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[
            ..., Awaitable[transition_route_group.ListTransitionRouteGroupsResponse]
        ],
        request: transition_route_group.ListTransitionRouteGroupsRequest,
        response: transition_route_group.ListTransitionRouteGroupsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.dialogflowcx_v3.types.ListTransitionRouteGroupsRequest):
                The initial request object.
            response (google.cloud.dialogflowcx_v3.types.ListTransitionRouteGroupsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = transition_route_group.ListTransitionRouteGroupsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(
        self,
    ) -> AsyncIterable[transition_route_group.ListTransitionRouteGroupsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterable[transition_route_group.TransitionRouteGroup]:
        async def async_generator():
            async for page in self.pages:
                for response in page.transition_route_groups:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)

==> google_cloud_dialogflow_cx-1.4.0-py2.py3-none-any.whl: google/cloud/dialogflowcx_v3/services/transition_route_groups/pagers.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import (
    Any,
    AsyncIterator,
    Awaitable,
    Callable,
    Sequence,
    Tuple,
    Optional,
    Iterator,
)

from google.cloud.dialogflowcx_v3.types import transition_route_group


class ListTransitionRouteGroupsPager:
    """A pager for iterating through ``list_transition_route_groups`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.dialogflowcx_v3.types.ListTransitionRouteGroupsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``transition_route_groups`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListTransitionRouteGroups`` requests and continue to iterate
    through the ``transition_route_groups`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.dialogflowcx_v3.types.ListTransitionRouteGroupsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., transition_route_group.ListTransitionRouteGroupsResponse],
        request: transition_route_group.ListTransitionRouteGroupsRequest,
        response: transition_route_group.ListTransitionRouteGroupsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.dialogflowcx_v3.types.ListTransitionRouteGroupsRequest):
                The initial request object.
            response (google.cloud.dialogflowcx_v3.types.ListTransitionRouteGroupsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = transition_route_group.ListTransitionRouteGroupsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(
        self,
    ) -> Iterator[transition_route_group.ListTransitionRouteGroupsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[transition_route_group.TransitionRouteGroup]:
        for page in self.pages:
            yield from page.transition_route_groups

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListTransitionRouteGroupsAsyncPager:
    """A pager for iterating through ``list_transition_route_groups`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.dialogflowcx_v3.types.ListTransitionRouteGroupsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``transition_route_groups`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListTransitionRouteGroups`` requests and continue to iterate
    through the ``transition_route_groups`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.dialogflowcx_v3.types.ListTransitionRouteGroupsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[
            ..., Awaitable[transition_route_group.ListTransitionRouteGroupsResponse]
        ],
        request: transition_route_group.ListTransitionRouteGroupsRequest,
        response: transition_route_group.ListTransitionRouteGroupsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.dialogflowcx_v3.types.ListTransitionRouteGroupsRequest):
                The initial request object.
            response (google.cloud.dialogflowcx_v3.types.ListTransitionRouteGroupsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = transition_route_group.ListTransitionRouteGroupsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(
        self,
    ) -> AsyncIterator[transition_route_group.ListTransitionRouteGroupsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[transition_route_group.TransitionRouteGroup]:
        async def async_generator():
            async for page in self.pages:
                for response in page.transition_route_groups:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
